;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "auto-dark" "20251006.358"
  "Automatically set the dark-mode theme based on system status."
  '((emacs "24.4"))
  :url "https://github.com/LionyxML/auto-dark-emacs"
  :commit "a71e791e47d09c5bf4bcbc2bbd7300b71ff72f1a"
  :revdesc "a71e791e47d0"
  :keywords '("macos" "windows" "linux" "themes" "tools" "faces")
  :authors '(("Tim Harper" . "timcharperatgmaildotcom")
             ("Vincent Zhang" . "seagle0128@gmail.com")
             ("Jonathan Arnett" . "jonathan.arnett@protonmail.com")
             ("Greg Pfeil" . "greg@technomadic.org"))
  :maintainers '(("Tim Harper" . "timcharperatgmaildotcom")
                 ("Vincent Zhang" . "seagle0128@gmail.com")
                 ("Jonathan Arnett" . "jonathan.arnett@protonmail.com")
                 ("Greg Pfeil" . "greg@technomadic.org")))
